---------------
-- Version 1.07
---------------

local E, L, V, P, G, _ =  unpack(ElvUI);
local DT = E:GetModule('DataTexts')

local labelType = 2 -- 1 = text, 2 = icon, 3 = icon + text
local lastPanel
local displayString = "---"
local _hex
local red = "|cffc74040"
local orange = "|cffda8c4f"
local Currencies = {823, 944, 980, 824, 1101, 994, 1129, 1191, 1166}
-- local state ={true, true, true, true, true, true, true, true, true} -- old way to enable/disable currency-tracking
local MAX = 9

--[[ Keeping this here for reference sake
local ApexisCrystals = {823}
local ArtifactFragments = {944}
local DingyIronCoins = {980}
local GarrisonResources = {824}
local Oil = {1101}
local SealOfTemperedFate = {994}
local SealOfInevitableFate = {1129}
local Valor = {1191}
local TimewarpedBadge = {1166}
]]

V['ElvUI_DraenorCurrency'] = {
	['AC'] = true,
	['AF'] = true,
	['DIC'] = true,
	['GR'] = true,
	['Oil'] = true,
	['SoTF'] = true,
	['SoIF'] = true,
	['VR'] = true,
	['TB'] = true,
}

local function ToggleOption(name)
	if E.private['ElvUI_DraenorCurrency'][name] then
		E.private['ElvUI_DraenorCurrency'][name] = false
	else
		E.private['ElvUI_DraenorCurrency'][name] = true
	end
end

local function GetOption(name)
	if E.private['ElvUI_DraenorCurrency'] then
		return E.private['ElvUI_DraenorCurrency'][name]
	end
end

local menu = {
	{ text = 'ElvUI Draenor Currencies Options', isTitle = true , notCheckable = true },
	{ text = 'Show Apexis Crystals', checked = function() return GetOption('AC') end, func = function() ToggleOption('AC') end },
	{ text = 'Show Artifact Fragments', checked = function()  return GetOption('AF') end, func = function() ToggleOption('AF') end },
	{ text = 'Show Dingy Iron Coins', checked = function() return GetOption('DIC') end, func = function() ToggleOption('DIC') end },
	{ text = 'Show Garrison Resources', checked = function() return GetOption('GR') end, func = function() ToggleOption('GR') end },
	{ text = 'Show Oil', checked = function() return GetOption('Oil') end, func = function() ToggleOption('Oil') end },
	{ text = 'Show Seal of Tempered Fate', checked = function() return GetOption('SoTF') end, func = function() ToggleOption('SoTF') end },
	{ text = 'Show Seal of Inevitable Fate', checked = function() return GetOption('SoIF') end, func = function() ToggleOption('SoIF') end },
	{ text = 'Show Valor', checked = function() return GetOption('VR') end, func = function() ToggleOption('VR') end },
	{ text = 'Show Timewarped Badge', checked = function() return GetOption('TB') end, func = function() ToggleOption('TB') end },
}

local menuFrame = CreateFrame("Frame", "ElvUI_DraenorCurrencyMenuFrame", E.UIParent, 'UIDropDownMenuTemplate')

local function getCurrenyCap(name)
	local cap = 0
	if name == "Apexis Crystal" then cap = 0
	elseif name == "Artifact Fragment" then cap = 1000
	elseif name == "Dingy Iron Coins" then cap = 20000
	elseif name == "Garrison Resources" then cap = 10000
	elseif name == "Oil" then cap = 100000
	elseif name == "Seal of Tempered Fate" then cap = 20
	elseif name == "Seal of Inevitable Fate" then cap = 10
	elseif name == "Valor" then cap = 5000
	elseif name == "Timewarped Badge" then cap = 0
	end
	return cap
end

local function ColorValue(name, currency)
	local color
	local cap = getCurrenyCap(name)
	local percent = currency * (100 / cap)
	
	if percent < 70 then color = _hex
	elseif percent >= 70 and percent < 90 then color = orange
	elseif percent >= 90 then color = red
	end

	if cap == 0 then return _hex
	else return color
	end
end

local function OnEvent(self, event, ...)
	lastPanel = self
	
	local _text = "---"
	if not _hex then return end
	
	for i = 1, MAX do
		if i == 1 then 
			displayString = '' 
		end
		local index = Currencies[i]
		local name, count, icon, earnedThisWeek, weeklyMax, totalMax, isDiscovered = GetCurrencyInfo(index)
		if name and isDiscovered then
			if name == "Apexis Crystal" and GetOption('AC') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end
			if name == "Artifact Fragment" and GetOption('AF') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end
			if name == "Dingy Iron Coins" and GetOption('DIC') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end
			if name == "Garrison Resources" and GetOption('GR') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end
			if name == "Oil" and GetOption('Oil') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end
			if name == "Seal of Tempered Fate" and GetOption('SoTF') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end
			if name == "Seal of Inevitable Fate" and GetOption('SoIF') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end
			if name == "Valor" and GetOption('VR') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end
			if name == "Timewarped Badge" and GetOption('TB') then
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
			end

--[[ part of old script, keeping this here in case it might still come in handy
				if(i ~= 1) then _text = " " else _text = "" end
				local texture = format('|T%s:14:14:0:0:64:64:4:60:4:60|t', icon)
				words = { strsplit(" ", name) }
				for _, word in ipairs(words) do
					_text = _text .. string.sub(word,1,1)
				end
				local str
				if labelType == 1 then
					str = tostring(_text..": ".._hex..count.."|r")
				elseif labelType == 2 then
					str = tostring(texture..":"..ColorValue(name, count)..count.._hex.."|r  ")
				elseif labelType == 3 then
					str = tostring(texture.." ".._text..": ".._hex..count.."|r")
				end
				displayString = displayString..str
]]

		elseif i == 1 and not name and not count then 
			displayString = tostring(_hex.."---")
		end
	end	
	if self then 
		self.text:SetFormattedText(displayString)
	end
	displayString = "---"

end

local function OnEnter(self)
	local r1, g1, b1, r2, g2, b2 = HIGHLIGHT_FONT_COLOR.r, HIGHLIGHT_FONT_COLOR.g, HIGHLIGHT_FONT_COLOR.b, NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b;
	DT:SetupTooltip(self)
	DT.tooltip:AddDoubleLine("Right-Click:", "Opens Datatext Options Menu", r1, g1, b1, r2, g2, b2)
	if lastPanel ~= nil then
		OnEvent(lastPanel)
	end
	DT.tooltip:Show()
end

local function OnClick(self, btn)
	if btn == "RightButton" then
		DT.tooltip:Hide();
		EasyMenu(menu, menuFrame, 'cursor', 0, 100, 'MENU', 3)
	end
end

local function ValueColorUpdate(hex, r, g, b)
	_hex = hex
	if lastPanel ~= nil then
		OnEvent(lastPanel)
	end
end
E['valueColorUpdateFuncs'][ValueColorUpdate] = true

--[[
	DT:RegisterDatatext(name, events, eventFunc, updateFunc, clickFunc, onEnterFunc)

	name - name of the datatext (required)
	events - must be a table with string values of event names to register
	eventFunc - function that gets fired when an event gets triggered
	updateFunc - onUpdate script target function
	click - function to fire when clicking the datatext
	onEnterFunc - function to fire OnEnter
]]
DT:RegisterDatatext('DraenorCurrencies', {'PLAYER_LOGIN', 'PLAYER_ENTERING_WORLD', 'PLAYER_MONEY', 'PLAYER_TRADE_MONEY', 'TRADE_MONEY_CHANGED', 'SPELLS_CHANGED'}, OnEvent, nil, OnClick, OnEnter) hooksecurefunc("BackpackTokenFrame_Update", function(...) OnEvent(lastPanel) end)
